'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

var _objectSpread = require('@babel/runtime/helpers/objectSpread2');
var _objectWithoutProperties = require('@babel/runtime/helpers/objectWithoutProperties');
var PropTypes = require('prop-types');
var core = require('@westpac/core');
require('@babel/runtime/helpers/taggedTemplateLiteral');
require('@babel/runtime/helpers/defineProperty');
var body = require('@westpac/body');
var jsxRuntime = require('@emotion/react/jsx-runtime');
require('react');

function _interopDefault (e) { return e && e.__esModule ? e : { 'default': e }; }

var PropTypes__default = /*#__PURE__*/_interopDefault(PropTypes);

var _excluded$1 = ["state"];
var Well$1 = function Well(_ref) {
  var tag = _ref.state.tag,
    rest = _objectWithoutProperties(_ref, _excluded$1);
  return jsxRuntime.jsx(body.Body, _objectSpread({
    tag: tag
  }, rest));
};
// ==============================
// Styles
// ==============================

var wellStyles = function wellStyles() {
  var mq = core.useMediaQuery();
  var _useBrand = core.useBrand(),
    COLORS = _useBrand.COLORS,
    SPACING = _useBrand.SPACING;
  return mq({
    label: core.getLabel('well'),
    padding: [SPACING(2), null, SPACING(4)],
    marginBottom: SPACING(3),
    backgroundColor: COLORS.light,
    border: "1px solid ".concat(COLORS.border),
    borderRadius: '0.1875rem',
    // Nested Well styling
    '& > &': {
      backgroundColor: '#fff',
      margin: "".concat(SPACING(2), " 0")
    }
  })[0];
};

// ==============================
// Attributes
// ==============================

var wellAttributes = function wellAttributes() {
  return null;
};

// ==============================
// Exports
// ==============================

var defaultWell = {
  component: Well$1,
  styles: wellStyles,
  attributes: wellAttributes
};

var pkg = {
	name: "@westpac/well",
	version: "2.2.0",
	description: "Simple containers used to highlight content",
	homepage: "https://gel.westpacgroup.com.au/design-system",
	repository: "https://github.com/WestpacGEL/GEL/tree/master/components/well",
	license: "GPL-3.0+",
	author: "Westpac GEL Team <gel@westpac.com.au>",
	contributors: [
		{
			name: "Dominik Wilkowski",
			email: "Hi@Dominik-Wilkowski.com",
			url: "https://dominik-wilkowski.com"
		},
		{
			name: "Jonathan Stening",
			email: "info@jonathanstening.com",
			url: "http://jonathanstening.com"
		},
		{
			name: "Jeremy Ortiz",
			email: "jeremy@jeremyortiz.io",
			url: "https://www.jeremyortiz.io/"
		},
		{
			name: "Flore Laforge",
			email: "florelaforge@gmail.com",
			url: "http://florelaforge.com/"
		}
	],
	main: "dist/westpac-well.cjs.js",
	module: "dist/westpac-well.esm.js",
	scripts: {
		start: "PACKAGE_NAME=well NODE_ENV=development webpack server --config ../../helpers/example/start.webpack.config.js",
		test: "exit 0 # start-server-and-test start http://localhost:8080 test:all",
		"test:all": "yarn test:integration",
		"test:dev": "start-server-and-test start http://localhost:8080 test:test-dev",
		"test:integration": "cypress run",
		"test:test-dev": "cypress open"
	},
	dependencies: {
		"@babel/runtime": "^7.14.8",
		"@westpac/body": "^2.2.0",
		"@westpac/core": "^3.2.0",
		"prop-types": "^15.7.2"
	},
	devDependencies: {
		"@emotion/react": "^11.10.6",
		cypress: "^8.0.0",
		react: "^18.2.0",
		"start-server-and-test": "^1.12.6"
	},
	peerDependencies: {
		"@emotion/react": "^11.10.6",
		react: "^18.2.0"
	},
	blender: {
		recipe: "blender/recipe.js"
	},
	components: [
		{
			name: "Well",
			src: "Well.tsx"
		}
	]
};

var _excluded = ["tag", "children", "overrides"];
// ==============================
// Component
// ==============================

var Well = function Well(_ref) {
  var _ref$tag = _ref.tag,
    tag = _ref$tag === void 0 ? 'div' : _ref$tag,
    children = _ref.children,
    componentOverrides = _ref.overrides,
    rest = _objectWithoutProperties(_ref, _excluded);
  var _useBrand = core.useBrand(),
    tokenOverrides = _useBrand.OVERRIDES[pkg.name],
    brandOverrides = _useBrand[pkg.name];
  var defaultOverrides = {
    Well: defaultWell
  };
  var state = _objectSpread({
    tag: tag,
    overrides: componentOverrides
  }, rest);
  var _overrideReconciler = core.overrideReconciler(defaultOverrides, tokenOverrides, brandOverrides, componentOverrides),
    _overrideReconciler$W = _overrideReconciler.Well,
    Well = _overrideReconciler$W.component,
    wellStyles = _overrideReconciler$W.styles,
    wellAttributes = _overrideReconciler$W.attributes;
  return jsxRuntime.jsx(Well, _objectSpread(_objectSpread(_objectSpread({}, rest), {}, {
    state: state
  }, wellAttributes(state)), {}, {
    css: wellStyles(state),
    children: children
  }));
};
Well.propTypes = {
  // ----------------------------- Warning --------------------------------
  // | These PropTypes are generated from the TypeScript type definitions |
  // |     To update them edit TypeScript types and run "yarn prop-types"  |
  // ----------------------------------------------------------------------
  /**
   * Children
   */
  children: PropTypes__default["default"].node,
  /**
   * The override API
   */
  overrides: PropTypes__default["default"].shape({
    Well: PropTypes__default["default"].shape({
      attributes: PropTypes__default["default"].func,
      component: PropTypes__default["default"].elementType,
      styles: PropTypes__default["default"].func
    })
  }),
  /**
   * Component tag
   */
  tag: PropTypes__default["default"].oneOfType([PropTypes__default["default"].func, PropTypes__default["default"].string])
};
Well.defaultProps = {
  tag: 'div'
};

exports.Well = Well;
